run_code_mode_host

Function run_code_mode_host 

pub fn run_code_mode_host(
    program: &CodeModeRecall,
    store: &dyn HostStore,
) -> Result<RecallBundle, CodeModeError>
Run a guest program against the host store. The wall-time and fuel budgets are enforced cooperatively on every step; the wasm sandbox enforces them preemptively under the wasm feature.